@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute the TF-IDF measure for ngram phrases
 
-our $VERSION = '0.0503';
+our $VERSION = '0.0504';
 
 use Moo;
 use strictures 2;
@@ -156,7 +156,7 @@ sub tfidf_by_file {
         }
     }
 
-    return $self->{file_tfidf};
+    return $self->file_tfidf;
 }
 
 1;
@@ -173,23 +173,23 @@ Text::TFIDF::Ngram - Compute the TF-IDF measure for ngram phrases
 
 =head1 VERSION
 
-version 0.0503
+version 0.0504
 
 =head1 SYNOPSIS
 
   use Text::TFIDF::Ngram;
 
-  my $obj = Text::TFIDF::Ngram->new(
+  my $t = Text::TFIDF::Ngram->new(
     files => [qw( foo.txt bar.txt )],
     size  => 3,
   );
 
-  my $w = $obj->tf( 'foo.txt', 'foo bar baz' );
-  my $x = $obj->idf('foo bar baz');
-  my $y = $obj->tfidf( 'foo.txt', 'foo bar baz' );
+  my $w = $t->tf( 'foo.txt', 'foo bar baz' );
+  my $x = $t->idf('foo bar baz');
+  my $y = $t->tfidf( 'foo.txt', 'foo bar baz' );
   printf "TF: %.3f, IDF: %.3f, TF-IDF: %.3f\n", $w, $x, $y;
 
-  my $z = $obj->tfidf_by_file;
+  my $z = $t->tfidf_by_file;
   print Dumper $z;
 
 =head1 DESCRIPTION
@@ -251,7 +251,7 @@ This is a computed attribute. Providing it to the constructor will be ignored.
 
 =head2 new
 
-  $obj = Text::TFIDF::Ngram->new(
+  $t = Text::TFIDF::Ngram->new(
     files       => \@files,
     size        => $size,
     stopwords   => $stopwords,
@@ -266,7 +266,7 @@ in, the ngrams of each file are stored in B<counts>.
 
 =head2 tf
 
-  $tf = $obj->tf( $file, $phrase );
+  $tf = $t->tf( $file, $phrase );
 
 Return the frequency of the given B<phrase> in the document B<file>.  This is
 not the "raw count" of the phrase, but rather the percentage of times it is
@@ -274,27 +274,27 @@ seen.
 
 =head2 idf
 
-  $idf = $obj->idf($phrase);
+  $idf = $t->idf($phrase);
 
 Return the inverse document frequency of a B<phrase> across all corpus
 documents.
 
 =head2 tfidf
 
-  $tfidf = $obj->tfidf( $file, $phrase );
+  $tfidf = $t->tfidf( $file, $phrase );
 
 Compute the TF-IDF weight for the given B<file> and B<phrase>.  If the phrase
 is not in the corpus, a warning is issued and undef is returned.
 
 =head2 tfidf_by_file()
 
-  $tfidf = $obj->tfidf_by_file;
+  $tfidf = $t->tfidf_by_file;
 
 Construct a HashRef of all files with all phrases and their B<tfidf> values.
 
 =head1 SEE ALSO
 
-The F<eg/analyze> and F<t/01-methods.t> files in this distribution
+The F<eg/*> and F<t/01-methods.t> files in this distribution
 
 L<https://en.wikipedia.org/wiki/Tf%E2%80%93idf>
 
